.app-snart .snart_lang_badges {
    vertical-align: sub;
}

.app-snart .field-truncated_value em {
    display: inline-block;
    font-style: normal;
    margin-left: 0.5rem;
    color: #59d;
    font-size: 90%;
}

.app-snart .snart_lang_badge {
    padding: 3px 5px;
    width: 25px;
    box-sizing: border-box;
    text-align: center;
    overflow: hidden;
    border-radius: 3px;
    line-height: 1.2;
    color: #fff;
    font-weight: 500;
    font-size: 11px;
    margin-right: 4px;
    user-select: none;
    text-transform: uppercase;
    display: inline-block;
}

.app-snart .snart_lang_badge:last-child {
    margin-right: 0;
}

.app-snart .snart_lang_badge-yes {
    background-color: #383;
}

.app-snart .snart_lang_badge-no {
    background-color: #d54;
}

.app-snart .column-key_nobr,
.app-snart .column-get_filled_trans,
.app-snart .field-key_nobr,
.app-snart .field-get_filled_trans {
    width: 1%;
    min-width: 50px;
    white-space: nowrap;
}