# Generated by Django 4.2.16 on 2024-10-18 22:20

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Constant",
            fields=[
                ("key", models.SlugField(primary_key=True, serialize=False, verbose_name="Key")),
                ("value", models.TextField(blank=True, default="", verbose_name="Value")),
                ("value_en", models.TextField(blank=True, default="", null=True, verbose_name="Value")),
                ("value_lt", models.TextField(blank=True, default="", null=True, verbose_name="Value")),
                ("value_uk", models.TextField(blank=True, default="", null=True, verbose_name="Value")),
                ("value_be", models.TextField(blank=True, default="", null=True, verbose_name="Value")),
                ("value_ru", models.TextField(blank=True, default="", null=True, verbose_name="Value")),
                ("context", models.TextField(blank=True, null=True, verbose_name="Context")),
            ],
            options={
                "verbose_name": "Constant",
                "verbose_name_plural": "Constants",
            },
        ),
    ]
